]> xenbits.xensource.com Git - seabios.git/commitdiff
Fix typos found by codespell
authorStefan Weil <sw@weilnetz.de>
Fri, 2 Oct 2015 06:46:40 +0000 (08:46 +0200)
committerKevin O'Connor <kevin@koconnor.net>
Fri, 9 Oct 2015 17:34:28 +0000 (13:34 -0400)
Signed-off-by: Stefan Weil <sw@weilnetz.de>
Signed-off-by: Kevin O'Connor <kevin@koconnor.net>
12 files changed:
scripts/kconfig/lxdialog/util.c
src/Kconfig
src/biosvar.h
src/bmp.c
src/fw/shadow.c
src/misc.c
src/sha1.c
src/std/bda.h
src/string.c
src/types.h
src/vgahooks.c
vgasrc/geodevga.h

index f7abdeb92af02188a48712ce48ab76f6b32f1d27..2a0d182e81da2820d950e069ee5df73a1187cc99 100644 (file)
@@ -376,7 +376,7 @@ void print_title(WINDOW *dialog, const char *title, int width)
 /*
  * Print a string of text in a window, automatically wrap around to the
  * next line if the string is too long to fit on one line. Newline
- * characters '\n' are propperly processed.  We start on a new line
+ * characters '\n' are properly processed.  We start on a new line
  * if there is no room for at least 4 nonblanks following a double-space.
  */
 void print_autowrap(WINDOW * win, const char *prompt, int width, int y, int x)
index b873cd392964a2c3d3ad9f56320d5120acb4a017..95bf087b810e17537ceaa8ec582eb2f720ec66f7 100644 (file)
@@ -20,7 +20,7 @@ choice
             Configure for an emulated machine (QEMU, Xen, KVM, or Bochs).
 
     config CSM
-       bool "Build as Compatibilty Support Module for EFI BIOS"
+       bool "Build as Compatibility Support Module for EFI BIOS"
        help
            Configure to be used by EFI firmware as Compatibility Support
            module (CSM) to provide legacy BIOS services.
index 58bcbcedb216957fa5c066de7f6ef900a423afe5..3b409573cfd77ecc1bdb265b5c524ebf1646e4d1 100644 (file)
@@ -12,7 +12,7 @@
 
 
 /****************************************************************
- * Interupt vector table
+ * Interrupt vector table
  ****************************************************************/
 
 #define GET_IVT(vector)                                         \
index d8e76b78959aebf1c11548e8de3fffa9a822f03b..96a2b3f226d532aee640441f2d440aa89cecc39d 100644 (file)
--- a/src/bmp.c
+++ b/src/bmp.c
@@ -1,6 +1,6 @@
 /*
 * Basic BMP data process and Raw picture data handle functions.
-* Could be used to adjust pixel data format, get infomation, etc.
+* Could be used to adjust pixel data format, get information, etc.
 *
 * Copyright (C) 2011 Wayne Xia <xiawenc@cn.ibm.com>
 *
index 4f00006bf01cc6445c6d018625165a7a6e745379..936ae285269aa1599ceb0b1fc57a1284aa0710cf 100644 (file)
@@ -65,7 +65,7 @@ make_bios_writable_intel(u16 bdf, u32 pam0)
     if (!(reg & 0x10)) {
         // QEMU doesn't fully implement the piix shadow capabilities -
         // if ram isn't backing the bios segment when shadowing is
-        // disabled, the code itself wont be in memory.  So, run the
+        // disabled, the code itself won't be in memory.  So, run the
         // code from the high-memory flash location.
         u32 pos = (u32)__make_bios_writable_intel + BIOS_SRC_OFFSET;
         void (*func)(u16 bdf, u32 pam0) = (void*)pos;
index 8caaf31d8a01f253c5e0e26d2f5aa170eea89f62..f02237c3665db421c4ddd635530da274f384414a 100644 (file)
@@ -56,7 +56,7 @@ void VISIBLE16
 handle_10(struct bregs *regs)
 {
     debug_enter(regs, DEBUG_HDL_10);
// dont do anything, since the VGA BIOS handles int10h requests
 }
 
 // NMI handler
index 352114f31b7ea7aceb1b32f99600b180bb1d0573..2ecb3cb89dd979913032ba1f5ace596524bb8125 100644 (file)
@@ -33,7 +33,7 @@ sha1_block(u32 *w, sha1_ctx *ctx)
     static const u32 sha_ko[4] = {
         0x5a827999, 0x6ed9eba1, 0x8f1bbcdc, 0xca62c1d6 };
 
-    /* change endianess of given data */
+    /* change endianness of given data */
     for (i = 0; i < 16; i++)
         w[i] = be32_to_cpu(w[i]);
 
@@ -120,7 +120,7 @@ sha1_do(sha1_ctx *ctx, const u8 *data32, u32 length)
 
     sha1_block(w, ctx);
 
-    /* need to switch result's endianess */
+    /* need to switch result's endianness */
     for (num = 0; num < 5; num++)
         ctx->h[num] = cpu_to_be32(ctx->h[num]);
 }
index c321266e2b895fa8859db2707a5d9a4810b349fe..4ad6605d4580116f638f381f26d4169c54f98682 100644 (file)
@@ -7,7 +7,7 @@
 
 
 /****************************************************************
- * Interupt vector table
+ * Interrupt vector table
  ****************************************************************/
 
 struct rmode_IVT {
index 2e4e437466266eaad1d9f27ec77067b1c78b6444..adb8198f84f44892cd5918c4766d6a8a96868426 100644 (file)
@@ -227,7 +227,7 @@ strtcpy(char *dest, const char *src, size_t len)
     return dest;
 }
 
-// locate first occurance of character c in the string s
+// locate first occurrence of character c in the string s
 char *
 strchr(const char *s, int c)
 {
index 097372cdb1a90ec1e336e632d35dedbc3215788a..19d9f6c145de09322a45f1a0ea098759b1f8502b 100644 (file)
@@ -70,7 +70,7 @@ extern void __force_link_error__only_in_16bit(void) __noreturn;
 # define VARFSEG __section(".discard.varfseg." UNIQSEC) __VISIBLE __weak
 // Designate a variable at a specific address in the f-segment.
 # define VARFSEGFIXED(addr) __section(".discard.varfixed." UNIQSEC) __VISIBLE __weak
-// Verify a variable is only accessable via 32bit "init" functions
+// Verify a variable is only accessible via 32bit "init" functions
 # define VARVERIFY32INIT __section(".discard.varinit." UNIQSEC)
 // Designate top-level assembler as 16bit only.
 # define ASM16(code) __ASM(code)
index 6a4acfeaf0e196f37b28923aef48f27f167a6bcf..48efb086cc34c83cd331d0d9f5fe89a0bee465f9 100644 (file)
@@ -124,7 +124,7 @@ getAMDRamSpeed(void)
 
 /* int 0x15 - 5f18
 
-   ECX = unknown/dont care
+   ECX = unknown/don't care
    EBX[3..0] Frame Buffer Size 2^N MiB
    EBX[7..4] Memory speed:
        0: SDR  66Mhz
index 61d78084d7a7a74486abfec9e9d50457581040d5..c99f54bb139112c939fb0760ef45b56d957c78ed 100644 (file)
@@ -2,7 +2,7 @@
 //
 // Copyright (C) 2009 Chris Kindt
 //
-// Writen for Google Summer of Code 2009 for the coreboot project
+// Written for Google Summer of Code 2009 for the coreboot project
 //
 // This file may be distributed under the terms of the GNU LGPLv3 license.
@@ -56,7 +56,7 @@ void VISIBLE16
 {
     debug_enter(regs, DEBUG_HDL_10);
-    // dont do anything, since the VGA BIOS handles int10h requests
+    // don't do anything, since the VGA BIOS handles int10h requests
 }
 